@@ -23,13 +23,17 @@ __all__ = (
     'DEFAULT_PLACEHOLDER_VIEW_TEMPLATE_NAME', 'DISPLAY_AUTH_LINK',
     'DEFAULT_PLACEHOLDER_EDIT_TEMPLATE_NAME', 'LAYOUT_CELL_UNITS', 
     'DISPLAY_LOGOUT_LINK', 'WAIT_BETWEEN_TEST_STEPS', 'WAIT_AT_TEST_END',
-    'PLUGIN_CLIPBOARD_KEY', 'DEBUG'
+    'RAISE_EXCEPTION_WHEN_PERMISSIONS_INSUFFICIENT', 'PLUGIN_CLIPBOARD_KEY',
+    'DEBUG'
 )
 
 from dash.conf import get_setting
 
 RESTRICT_PLUGIN_ACCESS = get_setting('RESTRICT_PLUGIN_ACCESS')
 
+RAISE_EXCEPTION_WHEN_PERMISSIONS_INSUFFICIENT = \
+    get_setting('RAISE_EXCEPTION_WHEN_PERMISSIONS_INSUFFICIENT')
+
 PLUGINS_MODULE_NAME = get_setting('PLUGINS_MODULE_NAME')
 
 ACTIVE_LAYOUT = get_setting('ACTIVE_LAYOUT')
